/* Reflow Oven Controller
 *
 * Copyright (C) 2020  Mario Hüttel <mario.huettel@gmx.net>
 *
 * This file is part of the Reflow Oven Controller Project.
 *
 * The reflow oven controller is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * GDSII-Converter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the reflow oven controller project.
 * If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file systick.h
 */

#ifndef __SYSTICK_H__
#define __SYSTICK_H__

#include <stdint.h>

/**
 * @brief Reload value for the systick timer.
 *
 * This value has to be configured to set the systick to a one milliscond tick interval
 * The default value is 168000, which results in a 1ms tick for 168 MHz CPU speed
 */
#define SYSTICK_RELOAD (168000UL)

/**
 * @brief Variable used by the systick_wait_ms function
 */
extern volatile uint32_t wait_tick_ms;

/**
 * @brief Systemclock in milliseconds.
 *
 * This value must not be reset during the whole runtime.
 *
 */
extern volatile uint64_t global_tick_ms;

/**
 * @brief Setup the Systick timer to generate a 1 ms tick
 */
void systick_setup(void);

/**
 * @brief Wait for x milliseconds
 *
 * This function is not reentrant and must not be called from an interrupt
 *
 * @warning Do not use in interrupt context
 * @param ms wait time in ms
 */
void systick_wait_ms(uint32_t ms);


#endif /* __SYSTICK_H__ */
